pub struct Duration(/* private fields */);Expand description
A Duration type to represent a span of time, typically used for system timeouts.
This type wraps std::time::Duration so we can implement traits on it
without coherence issues, just like if we were implementing this in the
stdlib.
Implementations
Sourceimpl Duration
impl Duration
Sourcepub fn new(secs: u64, nanos: u32) -> Duration
pub fn new(secs: u64, nanos: u32) -> Duration
Creates a new Duration from the specified number of whole seconds and
additional nanoseconds.
Sourcepub fn from_secs(secs: u64) -> Duration
pub fn from_secs(secs: u64) -> Duration
Creates a new Duration from the specified number of whole seconds.
Sourcepub fn from_millis(millis: u64) -> Self
pub fn from_millis(millis: u64) -> Self
Creates a new Duration from the specified number of milliseconds.
Sourcepub fn from_micros(micros: u64) -> Self
pub fn from_micros(micros: u64) -> Self
Creates a new Duration from the specified number of microseconds.
Sourcepub fn from_secs_f64(secs: f64) -> Duration
pub fn from_secs_f64(secs: f64) -> Duration
Creates a new Duration from the specified number of seconds represented
as f64.
Panics
This constructor will panic if secs is not finite, negative or overflows Duration.
Examples
use futures_time::time::Duration;
let dur = Duration::from_secs_f64(2.7);
assert_eq!(dur, Duration::new(2, 700_000_000));Sourcepub fn from_secs_f32(secs: f32) -> Duration
pub fn from_secs_f32(secs: f32) -> Duration
Creates a new Duration from the specified number of seconds represented
as f32.
Panics
This constructor will panic if secs is not finite, negative or overflows Duration.
Methods from Deref<Target = HostDuration>
pub const SECOND: Duration
pub const MILLISECOND: Duration
pub const MICROSECOND: Duration
pub const NANOSECOND: Duration
pub const ZERO: Duration
pub const MAX: Duration
1.53.0 · Sourcepub fn is_zero(&self) -> bool
pub fn is_zero(&self) -> bool
Returns true if this Duration spans no time.
Examples
use std::time::Duration;
assert!(Duration::ZERO.is_zero());
assert!(Duration::new(0, 0).is_zero());
assert!(Duration::from_nanos(0).is_zero());
assert!(Duration::from_secs(0).is_zero());
assert!(!Duration::new(1, 1).is_zero());
assert!(!Duration::from_nanos(1).is_zero());
assert!(!Duration::from_secs(1).is_zero());1.3.0 · Sourcepub fn as_secs(&self) -> u64
pub fn as_secs(&self) -> u64
Returns the number of whole seconds contained by this Duration.
The returned value does not include the fractional (nanosecond) part of the
duration, which can be obtained using subsec_nanos.
Examples
use std::time::Duration;
let duration = Duration::new(5, 730_023_852);
assert_eq!(duration.as_secs(), 5);To determine the total number of seconds represented by the Duration
including the fractional part, use as_secs_f64 or as_secs_f32
1.27.0 · Sourcepub fn subsec_millis(&self) -> u32
pub fn subsec_millis(&self) -> u32
Returns the fractional part of this Duration, in whole milliseconds.
This method does not return the length of the duration when represented by milliseconds. The returned number always represents a fractional portion of a second (i.e., it is less than one thousand).
Examples
use std::time::Duration;
let duration = Duration::from_millis(5_432);
assert_eq!(duration.as_secs(), 5);
assert_eq!(duration.subsec_millis(), 432);1.27.0 · Sourcepub fn subsec_micros(&self) -> u32
pub fn subsec_micros(&self) -> u32
Returns the fractional part of this Duration, in whole microseconds.
This method does not return the length of the duration when represented by microseconds. The returned number always represents a fractional portion of a second (i.e., it is less than one million).
Examples
use std::time::Duration;
let duration = Duration::from_micros(1_234_567);
assert_eq!(duration.as_secs(), 1);
assert_eq!(duration.subsec_micros(), 234_567);1.3.0 · Sourcepub fn subsec_nanos(&self) -> u32
pub fn subsec_nanos(&self) -> u32
Returns the fractional part of this Duration, in nanoseconds.
This method does not return the length of the duration when represented by nanoseconds. The returned number always represents a fractional portion of a second (i.e., it is less than one billion).
Examples
use std::time::Duration;
let duration = Duration::from_millis(5_010);
assert_eq!(duration.as_secs(), 5);
assert_eq!(duration.subsec_nanos(), 10_000_000);1.33.0 · Sourcepub fn as_millis(&self) -> u128
pub fn as_millis(&self) -> u128
Returns the total number of whole milliseconds contained by this Duration.
Examples
use std::time::Duration;
let duration = Duration::new(5, 730_023_852);
assert_eq!(duration.as_millis(), 5_730);1.33.0 · Sourcepub fn as_micros(&self) -> u128
pub fn as_micros(&self) -> u128
Returns the total number of whole microseconds contained by this Duration.
Examples
use std::time::Duration;
let duration = Duration::new(5, 730_023_852);
assert_eq!(duration.as_micros(), 5_730_023);1.33.0 · Sourcepub fn as_nanos(&self) -> u128
pub fn as_nanos(&self) -> u128
Returns the total number of nanoseconds contained by this Duration.
Examples
use std::time::Duration;
let duration = Duration::new(5, 730_023_852);
assert_eq!(duration.as_nanos(), 5_730_023_852);1.38.0 · Sourcepub fn as_secs_f64(&self) -> f64
pub fn as_secs_f64(&self) -> f64
Returns the number of seconds contained by this Duration as f64.
The returned value includes the fractional (nanosecond) part of the duration.
Examples
use std::time::Duration;
let dur = Duration::new(2, 700_000_000);
assert_eq!(dur.as_secs_f64(), 2.7);1.38.0 · Sourcepub fn as_secs_f32(&self) -> f32
pub fn as_secs_f32(&self) -> f32
Returns the number of seconds contained by this Duration as f32.
The returned value includes the fractional (nanosecond) part of the duration.
Examples
use std::time::Duration;
let dur = Duration::new(2, 700_000_000);
assert_eq!(dur.as_secs_f32(), 2.7);Sourcepub fn as_millis_f64(&self) -> f64
🔬This is a nightly-only experimental API. (duration_millis_float)
pub fn as_millis_f64(&self) -> f64
duration_millis_float)Returns the number of milliseconds contained by this Duration as f64.
The returned value includes the fractional (nanosecond) part of the duration.
Examples
#![feature(duration_millis_float)]
use std::time::Duration;
let dur = Duration::new(2, 345_678_000);
assert_eq!(dur.as_millis_f64(), 2_345.678);Sourcepub fn as_millis_f32(&self) -> f32
🔬This is a nightly-only experimental API. (duration_millis_float)
pub fn as_millis_f32(&self) -> f32
duration_millis_float)Returns the number of milliseconds contained by this Duration as f32.
The returned value includes the fractional (nanosecond) part of the duration.
Examples
#![feature(duration_millis_float)]
use std::time::Duration;
let dur = Duration::new(2, 345_678_000);
assert_eq!(dur.as_millis_f32(), 2_345.678);Trait Implementations
Sourceimpl AddAssign<Duration> for Instant
impl AddAssign<Duration> for Instant
Sourcefn add_assign(&mut self, rhs: Duration)
fn add_assign(&mut self, rhs: Duration)
+= operation. Read moreSourceimpl AddAssign for Duration
impl AddAssign for Duration
Sourcefn add_assign(&mut self, rhs: Duration)
fn add_assign(&mut self, rhs: Duration)
+= operation. Read moreSourceimpl From<Duration> for Duration
impl From<Duration> for Duration
Sourcefn from(inner: HostDuration) -> Self
fn from(inner: HostDuration) -> Self
Sourceimpl Into<Duration> for Duration
impl Into<Duration> for Duration
Sourcefn into(self) -> HostDuration
fn into(self) -> HostDuration
Sourceimpl IntoFuture for Duration
impl IntoFuture for Duration
Sourcetype IntoFuture = Sleep
type IntoFuture = Sleep
Sourcefn into_future(self) -> Self::IntoFuture
fn into_future(self) -> Self::IntoFuture
Sourceimpl IntoStream for Duration
impl IntoStream for Duration
Sourcetype IntoStream = Interval
type IntoStream = Interval
Sourcefn into_stream(self) -> Self::IntoStream
fn into_stream(self) -> Self::IntoStream
Sourceimpl Ord for Duration
impl Ord for Duration
Sourceimpl PartialOrd for Duration
impl PartialOrd for Duration
Sourceimpl SubAssign<Duration> for Instant
impl SubAssign<Duration> for Instant
Sourcefn sub_assign(&mut self, rhs: Duration)
fn sub_assign(&mut self, rhs: Duration)
-= operation. Read moreSourceimpl SubAssign for Duration
impl SubAssign for Duration
Sourcefn sub_assign(&mut self, rhs: Duration)
fn sub_assign(&mut self, rhs: Duration)
-= operation. Read more